package nl.amis.demo.josql;

import java.util.ArrayList;
import java.util.List;

import org.josql.Query;
import org.josql.QueryExecutionException;
import org.josql.QueryParseException;
import org.josql.QueryResults;

import nl.amis.demo.josql.domain.Person;

	/**
	 * A classroom normally holds some students.
	 * Demonstration of JoSQL capabilities.
	 * Disclaimer: This class is for demonstration purposes only, especially ExceptionHandling has not been implemented correctly
	 * @author aino_a
	 *
	 */
public class ClassRoom 
{
		/**
		 * All the students in the classroom
		 */
	private List<Person> students;
	
	public ClassRoom ()
	{
		students = new ArrayList<Person>();
	}
	
	public ClassRoom (List<Person> pStudents)
	{
		students = pStudents;
	}
	
		/**
		 * Find one or more students by its firstname.
		 * @param 	pVoornaam	The firstname to use in the Search
		 * @return	The list of students with the given firstname. Null when no students are found or an exception occurs.
		 */
	@SuppressWarnings("unchecked")
	public List<Person> findStudent (String pVoornaam)
	{
		String sql = "Select * from nl.amis.demo.josql.domain.Person where firstname = :studentname";
		Query q = new Query();
		try {
			q.parse(sql);
			q.setVariable("studentname", pVoornaam);
			QueryResults qr = q.execute(students);
			List<Person> foundStudents = qr.getResults();
			if (foundStudents.size() == 0)
				return null;
			else
				return foundStudents;
		} catch (QueryParseException e) {
			e.printStackTrace();
			return null;
		} catch (QueryExecutionException e) {
			e.printStackTrace();
			return null;
		}
	}

		/**
		 * Add a student to the classroom.
		 * @param pStudent
		 */
	public void addStudent (Person pStudent)
	{
		students.add(pStudent);
	}
	
	public List<Person> getStudents() {
		return students;
	}

	public void setStudents(List<Person> students) {
		this.students = students;
	}

}
